#
# spec file for package ghc-microlens-th
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name microlens-th
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.4.3.16
Release:        1.1
Summary:        Automatic generation of record lenses for microlens
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-microlens-devel
BuildRequires:  ghc-microlens-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-template-haskell-prof
BuildRequires:  ghc-th-abstraction-devel
BuildRequires:  ghc-th-abstraction-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-tagged-prof
%endif

%description
This package lets you automatically generate lenses for data types; code was
extracted from the lens package, and therefore generated lenses are fully
compatible with ones generated by lens (and can be used both from lens and
microlens).

This package is a part of the <http://hackage.haskell.org/package/microlens
microlens> family; see the readme
<https://github.com/stevenfontanella/microlens#readme on Github>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Dec 17 2024 Peter Simons <psimons@suse.com>
- Update microlens-th to version 0.4.3.16.
  [#] 0.4.3.16
  * [#182](https://github.com/stevenfontanella/microlens/pull/182) Support GHC 9.12.
* Fri Apr 19 2024 Peter Simons <psimons@suse.com>
- Update microlens-th to version 0.4.3.15.
  [#] 0.4.3.15
  * [#180](https://github.com/stevenfontanella/microlens/pull/180) [#181](https://github.com/stevenfontanella/microlens/pull/181) Support GHC 9.10.
* Tue Sep  5 2023 Peter Simons <psimons@suse.com>
- Update microlens-th to version 0.4.3.14.
  [#] 0.4.3.14
  * [#170](https://github.com/stevenfontanella/microlens/issues/170), [#171](https://github.com/stevenfontanella/microlens/pull/171) Support GHC 9.8.
* Sat Apr 29 2023 Peter Simons <psimons@suse.com>
- Update microlens-th to version 0.4.3.13.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/microlens-th-0.4.3.13/src/CHANGELOG.md
* Mon Apr  3 2023 Peter Simons <psimons@suse.com>
- Update microlens-th to version 0.4.3.12.
  [#] 0.4.3.12
  * [#164](https://github.com/stevenfontanella/microlens/pull/164), [#165](https://github.com/stevenfontanella/microlens/issues/165) Support template-haskell 2.19 (and GHC 9.6 by extension).
  [#] 0.4.3.11
  * [#161](https://github.com/stevenfontanella/microlens/pull/161) Fix GHC 9.4 warning for using `~` without TypeOperators
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Wed Dec 14 2022 Peter Simons <psimons@suse.com>
- Update microlens-th to version 0.4.3.11.
  Upstream has not updated the file "CHANGELOG.md" since the last
  release.
* Sat Aug 13 2022 Peter Simons <psimons@suse.com>
- Update microlens-th to version 0.4.3.10 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue May 11 2021 psimons@suse.com
- Update microlens-th to version 0.4.3.10.
  [#] 0.4.3.10
  * Port lens commit [fae336e1](https://github.com/ekmett/lens/commit/fae336e191748782cff023540bd25e3582ca93fb), "Close over kind variables when computing fixed type variables", fixing lens issue [#972](https://github.com/ekmett/lens/issues/972).
  * Allow building with template-haskell-2.18.
* Fri Jan  8 2021 psimons@suse.com
- Update microlens-th to version 0.4.3.9.
  [#] 0.4.3.9
  * Port lens commit [66e199ee](https://github.com/ekmett/lens/commit/66e199ee07f1aaf589faa2a8c661f6a722679959), fixing lens issue [#945](https://github.com/ekmett/lens/pull/945) — "Make the TH machinery handle PolyKinds more robustly".
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Thu Nov 19 2020 psimons@suse.com
- Update microlens-th to version 0.4.3.8.
  [#] 0.4.3.8
  * Fixup.
* Tue Nov 17 2020 psimons@suse.com
- Update microlens-th to version 0.4.3.7.
  [#] 0.4.3.7
  * Changes needed for template-haskell-2.17.
* Tue Oct  6 2020 psimons@suse.com
- Update microlens-th to version 0.4.3.6.
  [#] 0.4.3.6
  * Bumped th-abstraction.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add microlens-th at version 0.4.3.5.
